@@ -26,7 +26,7 @@
 # POSSIBILITY OF SUCH DAMAGE.
 import json
 import uuid
-from typing import Any, Dict, List, Tuple
+import typing as t
 
 from flask import Flask
 
@@ -214,7 +214,7 @@ def test_app_create_with_wrong_return():
     jsonrpc = JSONRPC(app, '/api', enable_web_browsable_api=True)
 
     @jsonrpc.method('app.fn1')
-    def fn2(s: str) -> Tuple[str, int, int, int]:  # pylint: disable=W0612
+    def fn2(s: str) -> t.Tuple[str, int, int, int]:  # pylint: disable=W0612
         return f'Bar {s}', 1, 2, 3
 
     with app.test_client() as client:
@@ -386,28 +386,28 @@ def test_app_create_with_rcp_batch():
 
     # pylint: disable=W0612
     @jsonrpc.method('get_user')
-    def get_user(uid: str) -> Dict[str, Any]:
+    def get_user(uid: str) -> t.Dict[str, t.Any]:
         return {'uid': uid, 'name': 'John Dee'}
 
     # pylint: disable=W0612
     @jsonrpc.method('notify_sum')
-    def notify_sum(numbers: List[int]) -> int:
+    def notify_sum(numbers: t.List[int]) -> int:
         s = sum(x**2 for x in numbers)
         return s
 
     # pylint: disable=W0612
     @jsonrpc.method('headers1')
-    def headers1() -> Tuple[float, int, List[Tuple[str, Any]]]:
+    def headers1() -> t.Tuple[float, int, t.List[t.Tuple[str, t.Any]]]:
         return 3.141592653589793, 200, [('X-Header-1-a', 'a1'), ('X-Header-1-b', 'b1')]
 
     # pylint: disable=W0612
     @jsonrpc.method('headers2')
-    def headers2() -> Tuple[float, int, Tuple[str, Any]]:
+    def headers2() -> t.Tuple[float, int, t.Tuple[str, t.Any]]:
         return 3.141592653589793, 201, ('X-Header-2-a', 'a2')
 
     # pylint: disable=W0612
     @jsonrpc.method('headers3')
-    def headers3() -> Tuple[float, int, Headers]:
+    def headers3() -> t.Tuple[float, int, Headers]:
         headers = Headers()
         headers.set('X-Header-3-a', 'a3')
         headers.set('X-Header-3-b', 'b3')
@@ -416,12 +416,12 @@ def test_app_create_with_rcp_batch():
 
     # pylint: disable=W0612
     @jsonrpc.method('headers4')
-    def headers4() -> Tuple[float, int, Dict[str, Any]]:
+    def headers4() -> t.Tuple[float, int, t.Dict[str, t.Any]]:
         return 3.141592653589793, 200, {'X-Header-4-a': 'a4', 'X-Header-4-b': 'b4'}
 
     # pylint: disable=W0612
     @jsonrpc.method('headers_duplicate')
-    def headers_duplicate() -> Tuple[float, int, Dict[str, Any]]:
+    def headers_duplicate() -> t.Tuple[float, int, t.Dict[str, t.Any]]:
         return (
             3.141592653589793,
             400,
